@@ -27,14 +27,13 @@ our @ObjectDependencies = (
     'Kernel::System::DateTime',
     'Kernel::System::Encode',
     'Kernel::System::Main',
-    'Kernel::System::Storable',
     'Kernel::System::SysConfig',
 );
 
 sub Configure {
     my ( $Self, %Param ) = @_;
 
-    $Self->Description('Update the OTRS translation files.');
+    $Self->Description('Update the Znuny translation files.');
     $Self->AddOption(
         Name        => 'language',
         Description => "Which language to use, omit to update all languages.",
@@ -44,7 +43,7 @@ sub Configure {
     );
     $Self->AddOption(
         Name        => 'module-directory',
-        Description => "Translate the OTRS module in the given directory.",
+        Description => "Translate the Znuny module in the given directory.",
         Required    => 0,
         HasValue    => 1,
         ValueRegex  => qr/.*/smx,
@@ -56,22 +55,29 @@ sub Configure {
         Required => 0,
         HasValue => 0,
     );
+    $Self->AddOption(
+        Name => 'keep-old',
+        Description =>
+            "Keep old language files (e.g. Kernel/Language/de_GeneralCatalog.pm). This is only needed if you want to diff these files.",
+        Required => 0,
+        HasValue => 0,
+    );
 
     my $Name = $Self->Name();
 
     $Self->AdditionalHelp(<<"EOF");
 
-<yellow>Translating OTRS</yellow>
+<yellow>Translating Znuny</yellow>
 
 Make sure that you have a clean system with a current configuration. No modules may be installed or linked into the system!
 
-    <green>otrs.Console.pl $Name --language ...</green>
+    <green>otrs.Console.pl $Name --language de</green>
 
 <yellow>Translating Extension Modules</yellow>
 
 Make sure that you have a clean system with a current configuration. The module that needs to be translated has to be installed or linked into the system, but only this one!
 
-    <green>otrs.Console.pl $Name --language ... --module-directory ...</green>
+    <green>otrs.Console.pl $Name --language de --module-directory \$PathToDirectory</green>
 EOF
 
     return;
@@ -770,7 +776,6 @@ sub WritePOFile {
 
     # Theoretically we could now also check for removed strings, but since the translations
     #   are handled by Weblate, this will not be needed as Weblate will handle that for us.
-
     Locale::PO->save_file_fromarray( $Param{TargetPOFile}, $POEntries )
         || die "Could not save file $Param{TargetPOFile}: $!";
 
@@ -926,6 +931,7 @@ sub WritePerlLanguageFile {
         $NewOut = <<"EOF";
 $Separator
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
+# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
 $Separator
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -1015,9 +1021,12 @@ EOF
 
     my $TargetFile = $Param{TargetFile};
 
-    if ( -e $TargetFile ) {
+    if ( -e $TargetFile && $Self->GetOption('keep-old') ) {
         rename( $TargetFile, "$TargetFile.old" ) || die $!;
     }
+    elsif ( -e $TargetFile ) {
+        unlink($TargetFile);
+    }
 
     $Kernel::OM->Get('Kernel::System::Main')->FileWrite(
         Location => $TargetFile,
